require "import"
import "android.media.AudioManager"
import "android.content.Context"
import "android.provider.Settings"
import "android.content.ComponentName"
import "android.content.Intent"
import "android.widget.Button"
import "android.widget.LinearLayout"
import "android.widget.SeekBar"
import "android.widget.TextView"
import "com.androlua.LuaDialog"
import "android.app.NotificationManager"
import "android.os.Build"

context = activity or service
audioManager = context.getSystemService(Context.AUDIO_SERVICE)
notificationManager = context.getSystemService(Context.NOTIFICATION_SERVICE)

function openZenAccessSettings()
  local intent = Intent()
  intent.setComponent(ComponentName("com.android.settings", "com.android.settings.Settings$ZenAccessSettingsActivity"))
  context.startActivity(intent)
end

function checkAndRequestZenModePermission()
  if Build.VERSION.SDK_INT >= Build.VERSION_CODES.M then
    if not notificationManager.isNotificationPolicyAccessGranted() then
      -- افتح إعدادات الوصول لوضع عدم الإزعاج تلقائيًا
      openZenAccessSettings()
      return false
    end
  end
  return true
end

function setSoundMode(mode)
  if not checkAndRequestZenModePermission() then
    service.postSpeak(500, "Permission required to change Do Not Disturb mode")
    return
  end

  local currentMode = audioManager.getRingerMode()
  if mode == "vibrate" and currentMode ~= AudioManager.RINGER_MODE_VIBRATE then
    audioManager.setRingerMode(AudioManager.RINGER_MODE_VIBRATE)
  elseif mode == "ring" and currentMode ~= AudioManager.RINGER_MODE_NORMAL then
    audioManager.setRingerMode(AudioManager.RINGER_MODE_NORMAL)
  elseif currentMode == AudioManager.RINGER_MODE_SILENT then
    print("The device is currently in silent mode.")
  end
end

function disableVibration()
  if not checkAndRequestZenModePermission() then
    service.postSpeak(500, "Permission required to change Do Not Disturb mode")
    return
  end

  if Build.VERSION.SDK_INT >= Build.VERSION_CODES.M then
    notificationManager.setInterruptionFilter(NotificationManager.INTERRUPTION_FILTER_NONE)
  end
end

function enableVibration()
  if not checkAndRequestZenModePermission() then
    service.postSpeak(500, "Permission required to change Do Not Disturb mode")
    return
  end

  if Build.VERSION.SDK_INT >= Build.VERSION_CODES.M then
    notificationManager.setInterruptionFilter(NotificationManager.INTERRUPTION_FILTER_ALL)
  end
end

-- عند بدء تنفيذ الكود الرئيسي، تحقق من الإذن وافتح إعدادات عدم الإزعاج إذا لم يكن الإذن ممنوحًا
if not checkAndRequestZenModePermission() then
  service.postSpeak(500, "Please grant Do Not Disturb access and try again.")
else
  -- أكمل تنفيذ الكود هنا بعد التحقق من الإذن
  local currentMode = audioManager.getRingerMode()
  if currentMode == AudioManager.RINGER_MODE_NORMAL then
    setSoundMode("vibrate")
    service.postSpeak(500, "Phone mode: Vibrate")
  elseif currentMode == AudioManager.RINGER_MODE_VIBRATE then
    audioManager.setRingerMode(AudioManager.RINGER_MODE_SILENT)
    disableVibration()
    service.postSpeak(500, "Phone mode: Silent")
  elseif currentMode == AudioManager.RINGER_MODE_SILENT then
    setSoundMode("ring")
    enableVibration()
    service.playSoundTick()
    service.postSpeak(500, "Phone mode: Ringer")
  end
end